#!/bin/bash

#
# QUICK START EXAMPLES:
#
# Using with no arguments gives USAGE INFO
# 
# ./newinstall.sh install all
#
# ./newinstall.sh check links
#
#

WORKDIR=`echo $0 |sed -e "s/\(.*\)\/\(.*\)$/\1/"`
source ${WORKDIR}/installLib.sh

set -x

#source installLib.sh

alias verify_link=isdir
alias verify_link=islink
alias verify_file=isfile
alias cp="ambiguous cp"
alias mv="ambiguous mv"
alias mkdir="ambiguous mkdir"
alias rm="ambigous rm"
alias ln="ambiguous ln"


#NOTE: This script is designed to be run from /tmp/ip_update/ipitomy/scripts/

ROOTDIR=/usr/local/ipitomy


function install_first()
{
    mv_f /tmp/ip_update/ipitomy /usr/local/
	chmod 777 /usr/local/ipitomy
}

function install_agi()
{
	pushd /usr/local/ipitomy/archive/
	cp_rf "*.agi" /var/lib/asterisk/agi-bin/
}

function install_pear_packages()
{
	pushd /usr/local/ipitomy/archive
	tar -xf PEAR_Image.tgz -C /usr/share/pear/
	popd
}

function install_autoprovision()
{
	pushd /usr/local/ipitomy/archive
	cp_rf prov /usr/local/sbin/
	popd
}
function install_RAID()
{
	pushd /usr/local/ipitomy/archive
	cp_rf tw_cli /usr/local/sbin/
	popd
}
function install_Hotswap()
{
	pushd /usr/local/ipitomy/etc/udev/rules.d
	cp_rf 66-mdadm-hotplug.rules /etc/udev/rules.d
	popd
}
function install_links_first()
{

    #track_ln_sf /usr/local/ipitomy /var/www/html/php-test
    #track_ln_sf $ROOTDIR/web /var/www/html/ippbx
	#remove obsolete links
	rm -f /var/www/html/php-test
	rm -f /var/www/html/ippbx
    track_ln_sf /usr/local/ipitomy/web/login /usr/local/ipitomy/web/spc

    return $?
}



function install_asterisk_monitor()
{
    DIR=/var/spool/asterisk/monitor

    mkdir_p $DIR
    chmod a+rwx $DIR

    #verify_chmod a+rwx $DIR

    return 0
}


WEB_RECORDING_DIR=$ROOTDIR/web/recordings/monitor

function cleanup_asterisk_monitor()
{
    rm_rf $WEB_RECORDING_DIR
}

function install_asterisk_monitor_link()
{
    track_ln_sf /var/spool/asterisk/monitor $WEB_RECORDING_DIR
}


function install_asterisk_etc()
{
    # used to be rm -rf ... changed to rm_link
    rm_rf /etc/asterisk
}

function install_asterisk_etc_link()
{
    track_ln_sf $ROOTDIR/asterisk /etc/asterisk
}

SOUND_DIR=/var/lib/asterisk/sounds

function install_asterisk_sounds()
{
# set up sounds
    rm_rf $SOUND_DIR
}

function install_asterisk_sounds_link()
{
    track_ln_sf $ROOTDIR/web/asterisk/sound_files $SOUND_DIR
}


MOHMP3_DIR=/var/lib/asterisk/mohmp3

function install_asterisk_mohmp3()
{
#   	mv_f /var/lib/asterisk/mohmp3 ${MOHMP3_DIR}.old
   	mv_f /var/lib/asterisk/moh ${MOHMP3_DIR}.old
    filesystem=$(mount | grep 'on / type ext3' | awk '{print $1}')
	#undoing past change
    tune2fs -O dir_index $filesystem

}

# clean up the file system
function force_fsck()
{
	touch /forcefsck
	echo " -y -A -V" >/fsckoptions
}

function install_asterisk_mohmp3_link()
{
    track_ln_sf $MOHMP3_DIR /var/lib/asterisk/moh
    track_ln_sf $ROOTDIR/web/music_on_hold_files $MOHMP3_DIR
}

function install_yum_gcc()
{
#yum -y install gcc
true;
}

function install_aastra_firmware()
{
# copy aastra firmware
    cp_rf "$ROOTDIR/archive/*.st" /tftpboot
    cp_rf "$ROOTDIR/archive/*.bin" /tftpboot
    cp_rf "$ROOTDIR/archive/*.tftp" /tftpboot
    cp_rf "$ROOTDIR/archive/lang*.txt" /tftpboot
    cp_rf "$ROOTDIR/archive/*.conf" /tftpboot
}

function install_polycom_firmware()
{
	
    cp_rf "$ROOTDIR/archive/*.ld" /tftpboot
	cp_rf "$ROOTDIR/archive/*.cfg" /tftpboot
}

ZAPVER=1.4.10
ZAPARCHIVE=zaptel-$ZAPVER.tar.gz
function install_zaptel()
{
# need dev tools for zaptel
    cp_rf $ROOTDIR/archive/zaptel-$ZAPVER.tar.gz /usr/src
#build zaptel
    cd /usr/src
    tar xzvf zaptel-1.2.23.tar.gz 
    cd /usr/src/zaptel-1.2.23
    make install
    modprobe zaptel
    modprobe ztdummy

    service zaptel restart
}

function setx_on_scripts()
{
    chmod +x $ROOTDIR/scripts/*
}

function setp_on_all()
{
# Set file permissions
    $ROOTDIR/scripts/setperm.sh
}

#function install_sqlite()
#{
#install sqlite
    #cp_rf $ROOTDIR/archive/sqlite-2.8.17.bin /usr/bin/sqlite
    #chmod +x /usr/bin/sqlite
	#cp_rf $ROOTDIR/archive/php_mod/pdo_sqlite.so /usr/lib/php/modules
	#cp_rf $ROOTDIR/archive/php_mod/pdo.so /usr/lib/php/modules
	#cp_rf $ROOTDIR/archive/php_mod/sqlite.so /usr/lib/php/modules
	#cp_rf $ROOTDIR/etc/php.d/pdo.ini  /etc/php.d
	#cp_rf $ROOTDIR/etc/php.d/pdo_sqlite.ini  /etc/php.d
#}


function install_sox_files()
{
    cp_rf $ROOTDIR/archive/soxmix /usr/local/bin/soxmix
    cp_rf $ROOTDIR/archive/sox /usr/local/bin/sox
}

function install_sox_links()
{
# make sox link
    track_ln_sf /usr/local/bin/sox /usr/bin/sox
    track_ln_sf /usr/local/bin/soxmix /usr/bin/soxmix
}

function install_modprobeconf()
{
# copy modprobe.conf 
    cp_rf $ROOTDIR/etc/modprobe.conf /etc/
}

function install_sudoers()
{
# copy sudoers
    cp_rf $ROOTDIR/etc/sudoers /etc/sudoers
}

function install_hotswap_swraid()
{
    cp_rf $ROOTDIR/etc/udev/rules.d/66-mdadm-hotplug.rules /etc/udev/rules.d
    cp_rf $ROOTDIR/archive/handle-add-old /usr/local/sbin
    cp_rf $ROOTDIR/archive/handle-remove-old /usr/local/sbin
}

function install_logrotate()
{
# copy logrotate files
    cp_rf "$ROOTDIR/etc/logrotate.d/*" /etc/logrotate.d/
}
function install_syslog()
{
	if [ -f /var/log/asterisk/CallEventLog ]
	then
		chmod 644 /var/log/asterisk/CallEventLog
	else

	 	touch /var/log/asterisk/CallEventLog
		chmod 644 /var/log/asterisk/CallEventLog
	fi
  	cp_rf "$ROOTDIR/etc/syslog.conf" /etc/syslog.conf
	service syslog restart
	cp_rf "$ROOTDIR/archive/CELogd" /usr/local/sbin/CELogd
    chmod +x /usr/local/sbin/CELogd
	mkdir_p /var/spool/ipitomy
	mkfifo /var/spool/ipitomy/logger
	if [ ! -p /var/log/asterisk/queue_log ] 
	then
		mv_f /var/log/asterisk/queue_log /var/log/asterisk/queue_log.0	
		mkfifo /var/log/asterisk/queue_log
	fi

	if [ ! -f /var/log/asterisk/call_events.db ] 
	then
		cp_rf "$ROOTDIR/archive/call_events.db" /var/log/asterisk/call_events.db
	fi
}
function install_backupdir
{
	mkdir_p /var/backup
}

function install_xinetd()
{
# copy xinetd files
    cp_rf "$ROOTDIR/etc/xinetd.d/*" /etc/xinetd.d/
}

function install_g729()
{
# overwrite safe_asterisk
    cp_rf $ROOTDIR/archive/codec_g729.so /usr/lib/asterisk/modules/codec_g729.so
    chmod +rx /usr/lib/asterisk/modules/codec_g729.so
}

function install_ejabberd_files()
{
	cp_rf "$ROOTDIR/archive/ejabberd/ejabberd_xmlrpc.beam" /usr/lib/ejabberd/ebin/ejabberd_xmlrpc.beam
	cp_rf "$ROOTDIR/archive/ejabberd/ejabberd.cfg" /etc/ejabberd/ejabberd.cfg
	cp_rf "$ROOTDIR/archive/ejabberd/ejabberdctl.cfg" /etc/ejabberd/ejabberdctl.cfg
}

function install_RTPPage()
{
    #cp_rf $ROOTDIR/archive/app_rtppage.so /usr/lib/asterisk/modules/app_rtppage.so
    #chmod +rx /usr/lib/asterisk/modules/app_rtpage.so
    echo ""
}

function install_funcdevstate()
{
    #cp_rf $ROOTDIR/archive/func_devstate.so /usr/lib/asterisk/modules/func_devstate.so
    #chmod +rx /usr/lib/asterisk/modules/func_devstate.so
    echo ""
}

function install_res_features()
{
    #cp_rf $ROOTDIR/archive/res_features.so /usr/lib/asterisk/modules/res_features.so
    #chmod +rx /usr/lib/asterisk/modules/res_features.so
    echo ""
}

function install_asterisk_over_safe_asterisk()
{
# overwrite safe_asterisk
    cp_rf $ROOTDIR/archive/safe_asterisk /usr/sbin/safe_asterisk
    chmod +rx /usr/sbin/safe_asterisk
}

function install_fail2ban()
{
	cp_rf $ROOTDIR/archive/fail2ban_rpms.tgz /tmp/fail2ban_rpms.tgz
	pushd .
	cd /tmp
	tar xzf /tmp/fail2ban_rpms.tgz
	cd /tmp/fail2ban_rpms/
	rpm -Uvh *.rpm
	popd
	cp_rf $ROOTDIR/etc/fail2ban/filter.d/* /etc/fail2ban/filter.d/
	cp_rf $ROOTDIR/etc/fail2ban/action.d/* /etc/fail2ban/action.d/
	cp_rf $ROOTDIR/etc/fail2ban/fail2ban.conf /etc/fail2ban/fail2ban.conf
	chkconfig fail2ban off

}

function install_hosts_file()
{
   cp_rf $ROOTDIR/etc/hosts /etc/hosts
}


function install_issue_script()
{
# copy issue script
    cp_rf $ROOTDIR/etc/rc.local /etc/rc.local
# copy issue script
##    cp_rf $ROOTDIR/etc/init.d/ /etc/rc.local
}

function install_cp_archive()
{
    cp_rf "$ROOTDIR/archive/*" /tmp
    cd /tmp
}

function install_astribank_hook()
{
	cp_rf "$ROOTDIR/archive/astribank_hook" /usr/share/zaptel
}

function install_ipfifo()
{
	cp_rf "$ROOTDIR/archive/ipfifo" /usr/local/sbin/ipfifo
	chmod +x /usr/local/sbin/ipfifo
}

#function OBSOLETE_install_zend()
#{
# install zend optimizer
    #cd /tmp
    #tar xzvf /tmp/Zend*.gz
    #cd /tmp/ZendOptimizer-3.0.1-linux-glibc21-i386
    #./install.sh
    #cp_rf $ROOTDIR/etc/php.ini /etc
#}

function install_icloader()
{
    cd /usr/local
    tar xzvf /tmp/icloader.tgz

    ## cd ???
    ##./install.sh
}


function install_php_ini()
{
    cp_rf $ROOTDIR/etc/php.ini /etc

# Note, there is another httpd_restart call in zaptel function
#    service httpd graceful
}

function install_dnsmasq()
{
	cp_rf $ROOTDIR/etc/dnsmasq.conf /etc
	/sbin/chkconfig dnsmasq on
}


function install_cron_vmexpire()
{
# install cron task for deleting voicemail
    cp_rf "$ROOTDIR/etc/cron.daily/*" /etc/cron.daily
    # note we have moved these so the install function must clean them up
    rm_rf /etc/cron.daily/vmexpire
    rm_rf /etc/cron.daily/call_log_cleanup
    rm_rf /etc/cron.daily/ip_auto_backup
    rm_rf /etc/cron.weekly/ip_auto_backup
    rm_rf /etc/cron.monthly/ip_auto_backup
    chmod +x /etc/cron.daily/tmpwatch
}

function install_initd_scripts()
{
# copy init.d start scripts
    cp_rf "$ROOTDIR/etc/init.d/*" /etc/init.d/
    chkconfig --del asterisk
#   chkconfig --del zaptel 
	
	chkconfig --levels 235 ntpd on
    service ntpd restart

    chkconfig --levels 2345 httpd on
	chkconfig CELogd on
	chkconfig iptables on
	chkconfig --add tcpdump
	# turn off cups no idea why we'd need this
	chkconfig cups off
	chkconfig gpm off
	# turn off portmap as it's not used either
	chkconfig portmap off
	# we aren't using nfs so we can turn this off as well
	chkconfig nfslock off
	/sbin/service yum-updatesd stop
	chkconfig yum-updatesd off

	chkconfig bluetooth off
	chkconfig pcscd off
	chkconfig nfs off
	chkconfig autofs off
	chkconfig sendmail off
#chkconfig --levels 2345 mysqld on
#service mysqld start
}

function install_yum_php()
{
#yum -y update php
true;
}

#pear install DB

function install_yum_tftp()
{
#yum -y install tftp-server
true;
}

function install_apcupsd()
{
    cp_rf /usr/local/ipitomy/etc/apcupsd.conf /etc/apcupsd
}

function install_start_zaptel_and_httpd()
{
## These 2 lines used to be listed after 'yum -y install tftp'
    #chkconfig --add zaptel
    chkconfig --add asterisk

#service httpd restart
    #service zaptel restart
}

function install_nusoap()
{
	tar -xzf /usr/local/ipitomy/archive/nusoap.tgz -C /usr/share
}

function install_import_init_db()
{
# import and initialize database 
#usr/bin/mysql -u root < db/ipitomy_db.sql
true;
}

function install_wwwroot_touch()
{
# put blank index in www root directory
    touch /var/www/html/index.html
}


function install_meetme_dir()
{
	mkdir_p /var/spool/asterisk/meetme
}



function install_cdr_custom()
{
    mkdir_p /var/log/asterisk/cdr-custom
    touch /var/log/asterisk/cdr-custom/Master.csv
    chmod og=+rwx /var/log/asterisk/cdr-custom
    chmod og=+rw /var/log/asterisk/cdr-custom/*
}

function install_asterisk_service_restart()
{
    service asterisk restart
}

function install_flash_op_panel()
{
# set up flash operator panel
    chmod +x /etc/init.d/op_panel
    chmod +x /usr/local/ipitomy/fop/op_server.pl
    chkconfig --add op_panel
    chkconfig --levels 2345 op_panel on
    service op_panel restart
}


function cleanup_tmp()
{
    rm_rf /tmp/ip_update
    rm_rf /tmp/ipitomy_pbx*
}

function install_ipitomy_host_access()
{
    /usr/local/ipitomy/scripts/host_access_wrapper.php -setup
}
function install_ipitomy_httpd()
{
    /usr/local/ipitomy/scripts/httpd_wrapper.php -setup
}

function install_cmgr_recordings()
{
	mkdir_p /var/spool/asterisk/recordings	
}


#####################################
# net console stuff

function install_reload_init()
{
  echo "Re-loading Init"
  initPID=`telinit Q && sleep 2 && ps -e | sort -n| grep "init" | head -1 | awk '{print $1; }'`
  kill -9 $initPID
}

function install_netconsole()
{
    if [ 1 ]
	then

#first virtual console tty number to use
	START=7
	END=$START

	TMP=/tmp/ipitomyconsole.tmp
	TMPRC=/tmp/ipitomyconsolerc.tmp
	RC="/root/.bashrc"

	cp_rf /etc/inittab /tmp/bk-inittab


	if [ -f /usr/local/ipitomy/scripts/netconsole.php ]
	    then

	    echo "Installing Ipitomy Console for TTYs "$START"-"$END

# OLD METHOD
###cat /etc/inittab|sed -e "s/\(["$START"-"$END"]\)\(:2345:respawn:\)\(.*\)\(tty\)\(.*\)/\1\2\/usr\/local\/ipitomy\/scripts\/netconsole.php \4\5/" > $TMP

####INSERT="\/sbin\/mingetty --loginprog=\/usr\/local\/ipitomy\/scripts\/netconsole.php"


	    INSERT="\/sbin\/mingetty --autologin root "

            # If there is already a ttyN, modify existing entries

	    grep "^["$START"-"$END"]:2345:respawn:/sbin/mingetty " /etc/inittab

	    if [ $? -eq 0 ];
		then

	    cat /etc/inittab|sed -e "s/\(["$START"-"$END"]\)\(:2345:respawn:\)\(.*\)\(tty\)\(.*\)/\1\2$INSERT\4\5/" > $TMP

	    else
		# Add our netconsole stuff to inittab

		  cat /etc/inittab > $TMP
		  echo -e "\n#" >> $TMP

		i=$START
		while [ $i -le $END ]
		  do

		  echo "$i:2345:respawn:/sbin/mingetty --autologin root tty$i" >> $TMP
		  i=$[$i+1]
		  done
	    fi

  # atomic update 
	    mv_f $TMP /etc/inittab

  # Now update .bashrc entry


	    ID="IPNETCONSOLE"

	    touch $TMPRC $TMPRC.2
	    chmod 600 $TMPRC $TMPRC.2

	    echo "# THESE LINES WERE AUTO ADDED FOR $ID" > $TMPRC
	    echo "ipnc=\"n\"; tty | grep \"/dev/tty$START\" && ipnc=\"y\" && /usr/local/ipitomy/scripts/netconsole.php ; # $ID" >> $TMPRC
	    echo "if [ \$ipnc = \"y\" ]; then exit 0; fi; # $ID" >> $TMPRC

	    cat $RC | grep -v $ID > $TMPRC.2
	    cat $TMPRC >> $TMPRC.2

	    rm_rf $TMPRC
	    # atomic update
	    mv_f $TMPRC.2 $RC

	    install_reload_init


 #  echo "Killing Old TTYs"
 # i=$START
 #   while [ $i -le $END ]
 #     do
 #       app=`ps -e | grep mingetty | grep "tty"$i | awk '{ print $1; }'`
 #  echo     kill -9 $app
 #       i=$[$i+1]
 #   done

	else
	    echo "Could not find netconsole.php"
	    echo "You can only install that if IPITOMY scripts dir is installed."
	fi

    fi # end
}

function update_bashrc()
{
	/bin/sed -ri "s/grep 7 &&/grep \"\/dev\/tty7\" \&\& /" /root/.bashrc
}

function remove_netconsole()
{
    TMP=/tmp/ipitomyconsolerc.tmp
    RC=/root/.bashrc

    touch $TMP
    chmod 600 $TMP
    cat /etc/inittab | sed "s/--autologin root //" > $TMP
    cat $TMP > /etc/inittab

    cat $RC | grep -v "IPNETCONSOLE" > $TMP

    # atomic
    mv_f $TMP $RC

    install_reload_init
}

########################################
#
# A single function to call all link making functions

function DISABLEinstall_links()
{
    install_links_first
    install_asterisk_monitor_link
    install_asterisk_etc_link
    install_asterisk_sounds_link
    install_asterisk_mohmp3_link
    install_sox_links
}

########################################
# Should mimic behavior of original install.sh
#

function install_packages()
{
	KERNEL_VER=`/bin/uname -r`
	UPGRADE_VERSIONS="2.6.18-53.el5 2.6.18-54.el5 2.6.18-164.15.1.el5 2.6.18-194.26.1.el5"

	cd /usr/local/ipitomy/RPMS

	# I'm putting this in here to protect the souond files for the moment
	# we should remove this when we add multi-language support
	# It should be restored by the functions that update the sound link
	# that are called later in the update function
	rm_rf /var/lib/asterisk/sounds
	

	# if we on a previously known version update to current kernel
	for CVER in $UPGRADE_VERSIONS
	do
		if [ $CVER = $KERNEL_VER ]; then
			install_kernel	
			break;
		fi
	done
	# remove kernel rpm to prevent update errors
	rm_rf "kernel*.rpm"
	
	# ensure all asterisk and zaptel processes are stopped
	kill_asterisk_and_zaptel

	# check if asterisk is installed
	if [ -e /usr/sbin/asterisk ]; then

		AST_VER=`/usr/sbin/asterisk -V`
		if [ "$AST_VER" = "Asterisk 1.4.20.1" ]; then
			update_1_4_20_to_1_4_34
		fi
	else
		# asterisk is not installed to just follow same commands
		echo "Asterisk binary not found installing"
		update_1_4_20_to_1_4_34
	fi

	# run preinstall ops
	pre_rpm_install
	
	
	# this will eventually be the yum update call
	update_rpms
	
	post_rpm_install

}

function pre_rpm_install()
{
	TURN_CHAT_OFF=0
	CHAT_INST=`rpm -qa | grep ejabberd`
	if [ "$CHAT_INST" -ne "" ];
	then
		TURN_CHAT_OFF=1
	fi
		
}
	
function post_rpm_install()
{
	if [ $TURN_CHAT_OFF -eq 1 ]; 
	then
		chkconfig ejabberd off		
		killall -u ejabberd
	fi
}

# this function will eventually use the yum repo - but just fudge it for now
function update_rpms()
{
	
	# install the kmod it has issues with localinstall and localupdate
	# kmod - if you install with rpm -Uvh this works if you update with 
    #        localupdate it continuously tries to update
	rpm -Uvh kmod-dahdi*.rpm
	rm_rf "kmod-dahdi*.rpm"

	yum --disablerepo=base,updates,extras,addons,centosplus -y -c /usr/local/ipitomy/RPMS/yum.conf localupdate *.rpm 
	yum --disablerepo=base,updates,extras,addons,centosplus -y -c /usr/local/ipitomy/RPMS/yum.conf localinstall *.rpm
}

function kill_asterisk_and_zaptel()
{
	service asterisk stop
	killall -9 asterisk
	killall -9 safe_asterisk
	killall -9 asterisk
	service zaptel stop
	MODS="tor2 wct4xxp wcte11xp wcfxo wcfxs wctdm24xxp wcusb wctfxsusb torisa xpp_usb xpd_fxs xpd_fxo xpp ztdummy zaptel"
	for CMOD in $MODS
	do
		rmmod $CMOD	
	done
	
}

function install_kernel()
{
	THEDIR=`pwd`
	echo "TheDir = $THEDIR"
	rpm -i `ls kernel*.rpm`
    rm_rf kernel-2.6.18*.rpm
}

function update_1_4_20_to_1_4_34()
{
	INSTALLED=`/usr/sbin/asterisk -V`
	if [ "$INSTALLED" = "Asterisk 1.4.20.1" ]; then
		save_configs
		service asterisk stop
		service zaptel stop
		rmmod xpd-fxo
		rmmod xpd-fxs
		rmmod xpp-usb
		rmmod xpp
		rmmod zaptel
		rpm -e asterisk
		rpm -e zaptel
		rpm -e kernel-module-zaptel
		rpm -e libpri
		rpm -i yum-kmod*.rpm
		rpm -i libpri*.rpm
		rpm -i libtonezone*.rpm
		rpm -i kmod*.rpm
		rpm -i dahdi*.rpm
		rpm -i asterisk*.rpm
		restore_configs
	fi
	
}


function save_configs()
{
	pushd .
	cd /usr/local/ipitomy/asterisk
	tar czpf /tmp/astconfig.tgz *
	popd
}

function restore_configs()
{
	pushd .
	cd /usr/local/ipitomy/asterisk
	tar xzpf /tmp/astconfig.tgz
	popd
}
#install RSA key
function install_rsa_key()
{
	cp_rf $ROOTDIR/archive/id_rsa.pub /root/.ssh/authorized_keys2

}
#####################################
# Create Symlinks in /etc to conf/ for actively altered configuration file
#

function install_symlinks()
{
	rm_rf /etc/asterisk/astmanproxy.users
	rm_rf /etc/asterisk/astmanproxy.conf
	ln_sf /usr/local/ipitomy/conf/astmanproxy.users /etc/asterisk/astmanproxy.users 
	ln_sf /usr/local/ipitomy/conf/astmanproxy.conf /etc/asterisk/astmanproxy.conf
}

function install_menu_prompt()
{
	if [ ! -d  "/usr/local/ipitomy/web/asterisk/sound_files/custom/menu_prompts" ]; then
        mkdir_p /usr/local/ipitomy/web/asterisk/sound_files/custom/menu_prompts
    fi
	chmod 777 /usr/local/ipitomy/web/asterisk/sound_files/custom/menu_prompts
	chmod 777 /usr/local/ipitomy/web/asterisk/sound_files/custom/menu_prompts/*
}

function install_apache_config()
{
	cp_rf "/usr/local/ipitomy/etc/httpd.conf" /etc/httpd/conf/
	cp_rf "/usr/local/ipitomy/etc/ippbx.conf" /etc/httpd/conf.d/ippbx.conf
	# this is not needed remove it
	rm_rf "/etc/httpd/conf.d/proxy_ajp.conf"
	cp_rf "/usr/local/ipitomy/etc/mobile.conf" /etc/httpd/conf.d/mobile.conf
	
}

function install_all()
{
    install_first

	install_packages

    install_links_first

    install_asterisk_monitor
    cleanup_asterisk_monitor
    install_asterisk_monitor_link

    install_asterisk_etc
    install_asterisk_etc_link

    install_asterisk_sounds
    install_asterisk_sounds_link

    install_asterisk_mohmp3
    install_asterisk_mohmp3_link

    install_aastra_firmware
	install_polycom_firmware
    setx_on_scripts
    setp_on_all
    install_sox_files
    install_sox_links
    install_modprobeconf
    install_sudoers
    install_logrotate
	install_syslog
    install_ipfifo
    install_xinetd
    install_asterisk_over_safe_asterisk
    install_hosts_file
    install_issue_script
	
	install_g729
	install_ejabberd_files
	#install_RTPPage
	#install_funcdevstate
	#install_res_features

	install_meetme_dir
	install_agi
	#install_astribank_hook

    install_cp_archive
	install_autoprovision
	install_RAID
    install_hotswap_swraid
    install_pear_packages
    install_icloader
    install_php_ini

    install_cron_vmexpire
    install_initd_scripts
    install_start_zaptel_and_httpd
    install_import_init_db
    install_wwwroot_touch
    install_cdr_custom
    install_asterisk_service_restart
    install_nusoap
	install_symlinks
	install_cmgr_recordings
	install_dnsmasq
	install_fail2ban
	install_backupdir
	install_menu_prompt
	install_apcupsd
    cd ${WORKDIR}

	# Make sure this gets created
	if [ ! -f "/etc/asterisk/ipitomy.conf" ]; then
		touch /etc/asterisk/ipitomy.conf
		chmod og=+rw /etc/asterisk/ipitomy.conf
	fi


	cp_rf "/usr/local/ipitomy/etc/hosts.*" /etc/


	install_apache_config
    # commenting out and cleaning up
	#ln_sf /usr/sbin/ztcfg /sbin/
	if [ -f /sbin/ztcfg ]
	then
        rm_rf /sbin/ztcfg
    fi
    install_netconsole
	force_fsck
	cleanup_tmp
	setp_on_all
}

function update_all
{
	service httpd stop
    #Backup Prompts
    mkdir_p /tmp/ip_sound_backup 
	cp_rf /usr/local/ipitomy/web/asterisk/sound_files/custom /tmp/ip_sound_backup/
	cp_rf /usr/local/ipitomy/web/music_on_hold_files /tmp/ip_sound_backup/


	# move old directory to .old & only copy license file if we succeed in move
    preserve_dir /usr/local/ipitomy /tmp/ipitomy.old && cp_rf "/tmp/ipitomy.old/iplic.ic" /tmp/ip_update/ipitomy/iplic.ic
    chown apache:apache "/tmp/ip_update/ipitomy/iplic.ic"
    chmod +rw "/tmp/ip_update/ipitomy/iplic.ic"
	
	#Replace old configuration database
	cp_rf "/tmp/ipitomy.old/database/ipitomydb.db" /tmp/ip_update/ipitomy/database/ipitomydb.db

	#copy recordings directory
	cp_rf /tmp/ipitomy.old/queue_recordings/* /tmp/ip_update/ipitomy/queue_recordings
	
	
    install_first

    set +x
    install_packages
    set -x

    install_links_first

    install_asterisk_monitor
    cleanup_asterisk_monitor
    install_asterisk_monitor_link

    install_asterisk_etc
    install_asterisk_etc_link

    install_asterisk_sounds
    install_asterisk_sounds_link

    #install_asterisk_mohmp3
	#install_asterisk_mohmp3_link
	
    install_aastra_firmware
	install_polycom_firmware
    setx_on_scripts
    setp_on_all
    install_sox_files
    install_sox_links
    install_modprobeconf
    install_sudoers
    install_logrotate
	install_syslog
    install_ipfifo
    install_xinetd
    install_asterisk_over_safe_asterisk
	install_g729
	install_ejabberd_files
	#install_RTPPage
	#install_funcdevstate
	install_agi
	#install_res_features
    install_issue_script

    install_meetme_dir
    #install_astribank_hook

    install_cp_archive
	install_autoprovision
	install_RAID
    install_hotswap_swraid
	install_pear_packages
    install_icloader
    install_php_ini

    install_cron_vmexpire
    install_initd_scripts
    install_start_zaptel_and_httpd
    install_import_init_db
    install_wwwroot_touch
    install_cdr_custom
    install_asterisk_service_restart
	install_nusoap
	install_symlinks
	install_dnsmasq
	install_fail2ban
	update_bashrc
	install_apcupsd
    cd ${WORKDIR}

    # removed this line from updates.  We will have to have a better way to fix this if it's modified
   	#cp_rf "/usr/local/ipitomy/etc/hosts.*" /etc/ #CHANGE TO BACKUP hosts file if it is changed above

	install_apache_config
	#if [ ! -f  "/tmp/10_K_STACKS_DETECTED" ]; then
	    #ln_sf /usr/sbin/ztcfg /sbin/
	#fi

	# Make sure this gets created
	if [ ! -f "/etc/asterisk/ipitomy.conf" ]; then
		touch /etc/asterisk/ipitomy.conf
		chmod og=+rw /etc/asterisk/ipitomy.conf
	fi

    install_netconsole
#Replace sound files and MOH
	rm_rf /usr/local/ipitomy/web/asterisk/sound_files/custom/
	rm_rf /usr/local/ipitomy/web/music_on_hold_files/
	cp_rf /tmp/ip_sound_backup/custom /usr/local/ipitomy/web/asterisk/sound_files/
	cp_rf /tmp/ip_sound_backup/music_on_hold_files /usr/local/ipitomy/web/

	install_menu_prompt	
	
    filesystem=$(mount  | grep 'on / type ext3' | awk '{print $1}')
    tune2fs -O ^dir_index  $filesystem
	
	install_cmgr_recordings
#Make sure Drew's RSA key is on the system
	install_rsa_key

#Remove old FOP symlink
	rm_rf "/usr/local/fop"	
	chkconfig --del op_panel
	rm_rf /etc/init.d/op_panel
	

	cleanup_tmp	
#Upgrade old database backups to new metafiel format
	if [ ! -d "/var/backup" ]; then
		install_backupdir
		ls -1 /usr/local/ipitomy/database/*.tgz | xargs -l /usr/local/ipitomy/scripts/backup_agent.php upgrade 
	fi
	setp_on_all
#Restart services after all changes [Changed back to /sbin/reboot] 
	#service xinetd restart
	#service httpd graceful

	force_fsck
	/sbin/reboot
}

function install_henry_apps
{
    install_sudoers
    install_ipitomy_host_access
    install_ipitomy_httpd
    install_netconsole
}

function check_links()
{
    lib_check_links
}
function repair_links()
{
    lib_repair_links
}


function test_false()
{
    false
}

function test_true()
{
    true
}

function test_star_spaces()
{
    
    mkdir_p testdir.1
    mkdir_p testdir.2
    cd testdir.1
    touch "file spaced 1.e"
    touch "file spaced 2.q"
    touch "nospaces1.x"
    cd ../testdir.2
    cp_rf "../testdir.1/*" .

}


function test_link_autoremove()
{
    echo "Should see one message about removing existing link:"

    mkdir testdir.1
    cd testdir.1

    mkdir_p adir
    touch adir/foo;touch adir/boo

    mkdir_p bdir
    touch bdir/2foo;touch bdir/2boo

    ln_sf adir linka
    ln_sf bdir linka
}
